@@ -154,7 +154,7 @@ RSpec.describe Dry::Types::Sum do
 
     it "returns boolean" do
       expect(type.===("hello")).to eql(true)
-      expect(type === (nil)).to eql(false)
+      expect(type.nil?).to eql(false)
     end
 
     context "in case statement" do
@@ -206,6 +206,20 @@ RSpec.describe Dry::Types::Sum do
       expect(type.valid?(nil)).to eql(true)
       expect(type.valid?(10)).to eql(true)
     end
+
+    it "works with sum of complex constructors" do
+      a = Dry::Types["string"].constrained(size: 2) | Dry::Types["hash"]
+      b = Dry::Types["string"].constrained(size: 1) | Dry::Types["hash"]
+
+      c = a.constructor { |x| x.is_a?(Hash) ? x : x.downcase } |
+          b.constructor { |x| x.is_a?(Hash) ? x : x.upcase }
+
+      expect(c.call({})).to eq({})
+      expect(c.call("A")).to eq("A")
+      expect(c.call("aa")).to eq("aa")
+
+      expect { c.call("aaa") }.to raise_error(Dry::Types::ConstraintError)
+    end
   end
 
   describe "#rule" do
@@ -289,6 +303,31 @@ RSpec.describe Dry::Types::Sum do
         )
       end
     end
+
+    context "with dry-struct types" do
+      before { require "dry-struct" }
+
+      let(:struct_a) do
+        Class.new(Dry::Struct) do
+          def self.name
+            "TestStructA"
+          end
+        end
+      end
+
+      let(:struct_b) do
+        Class.new(Dry::Struct) do
+          def self.name
+            "TestStructB"
+          end
+        end
+      end
+
+      it "works with sum of two structs" do
+        sum_type = struct_a | struct_b
+        expect { sum_type.to_s }.not_to raise_error
+      end
+    end
   end
 
   context "with map type" do
